@@ -36,7 +36,7 @@ use strict;
 use vars qw($VERSION $AUTOLOAD %stdCase);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.63';
+$VERSION = '1.65';
 
 sub ProcessPNG_tEXt($$$);
 sub ProcessPNG_iTXt($$$);
@@ -973,13 +973,20 @@ sub FoundPNG($$$$;$$$$)
                 undef $processProc if $wasCompressed and $processProc and $processProc eq \&ProcessPNG_Compressed;
                 # rewrite this directory if necessary (but always process TextualData normally)
                 if ($outBuff and not $processProc and $subTable ne \%Image::ExifTool::PNG::TextualData) {
-                    return 1 unless $$et{EDIT_DIRS}{$dirName};
-                    $$outBuff = $et->WriteDirectory(\%subdirInfo, $subTable);
-                    if ($tagName eq 'XMP' and $$outBuff) {
-                        # make sure the XMP is marked as read-only
-                        Image::ExifTool::XMP::ValidateXMP($outBuff,'r');
+                    # allow JUMBF to be deleted (may want to expand this for other types too?)
+                    if ($dirName eq 'JUMBF' and $$et{DEL_GROUP}{$dirName}) {
+                        $$outBuff = '';
+                        ++$$et{CHANGED};
+                        $et->VPrint(0, "  Deleting $dirName");
+                    } else {
+                        return 1 unless $$et{EDIT_DIRS}{$dirName};
+                        $$outBuff = $et->WriteDirectory(\%subdirInfo, $subTable);
+                        if ($tagName eq 'XMP' and $$outBuff) {
+                            # make sure the XMP is marked as read-only
+                            Image::ExifTool::XMP::ValidateXMP($outBuff,'r');
+                        }
+                        DoneDir($et, $dirName, $outBuff, $$tagInfo{NonStandard});
                     }
-                    DoneDir($et, $dirName, $outBuff, $$tagInfo{NonStandard});
                 } else {
                     $processed = $et->ProcessDirectory(\%subdirInfo, $subTable, $processProc);
                 }
@@ -1374,7 +1381,7 @@ sub ProcessPNG($$)
     my $datCount = 0;
     my $datBytes = 0;
     my $fastScan = $et->Options('FastScan');
-    my $md5 = $$et{ImageDataMD5};
+    my $hash = $$et{ImageDataHash};
     my ($n, $sig, $err, $hbuf, $dbuf, $cbuf);
     my ($wasHdr, $wasEnd, $wasDat, $doTxt, @txtOffset);
 
@@ -1454,7 +1461,7 @@ sub ProcessPNG($$)
             if ($datCount and $chunk ne $datChunk) {
                 my $s = $datCount > 1 ? 's' : '';
                 print $out "$fileType $datChunk ($datCount chunk$s, total $datBytes bytes)\n";
-                print $out "$$et{INDENT}(ImageDataMD5: $datBytes bytes of $datChunk data)\n" if $md5;
+                print $out "$$et{INDENT}(ImageDataHash: $datBytes bytes of $datChunk data)\n" if $hash;
                 $datCount = $datBytes = 0;
             }
         }
@@ -1541,13 +1548,8 @@ sub ProcessPNG($$)
                 }
             # skip over data chunks if possible/necessary
             } elsif (not $validate or $len > $chunkSizeLimit) {
-                if ($md5) {
-                    while ($len) {
-                        my $n = $len > 65536 ? 65536 : $len;
-                        $raf->Read($dbuf,$n) == $n or last;
-                        $md5->add($dbuf);
-                        $len -= $n;
-                    }
+                if ($hash) {
+                    $et->ImageDataHash($raf, $len);
                     $raf->Read($cbuf, 4) == 4 or $et->Warn('Truncated data'), last;
                 } else {
                     $raf->Seek($len + 4, 1) or $et->Warn('Seek error'), last;
@@ -1570,7 +1572,7 @@ sub ProcessPNG($$)
             $et->Warn("Corrupted $fileType image") unless $wasEnd;
             last;
         }
-        $md5->add($dbuf) if $md5 and $datChunk;   # add to MD5 if necessary
+        $hash->add($dbuf) if $hash and $datChunk;   # add to hash if necessary
         if ($verbose or $validate or ($outfile and not $fastScan)) {
             # check CRC when in verbose mode (since we don't care about speed)
             my $crc = CalculateCRC(\$hbuf, undef, 4);
